# ncmpy - A curses-based MPD client written in Python

----

**ncmpy** is a curses-based client for the [Music Player Daemon][mpd].

## Features

-   Playback control.
-   Queue control.
-   Song rating.
-   Database control.
-   Auto lyrics fetching and saving.
-   Lyrics highlighting.
-   Artist-Album view.
-   Search by tags.
-   Output control.


## Install

See INSTALL.

## License

See LICENSE.

----

## Acknowledgements

Lyrics plugin is adapted from ttplyrics: http://code.google.com/p/ttplyrics/


[mpd]: http://musicpd.org/
